#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
class geometry(Group):
    """
    Help not available.
    """

    fluent_name = "geometry"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread']

    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of geometry.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of geometry.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of geometry.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of geometry.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of geometry.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of geometry.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of geometry.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .phase_22 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .flow_spec import flow_spec as flow_spec_cls
from .mass_flow import mass_flow as mass_flow_cls
from .mass_flux import mass_flux as mass_flux_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
class recirculation_outlet_child(Group):
    """
    'child_object_type' of recirculation_outlet.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'flow_spec',
         'mass_flow', 'mass_flux', 'solar_fluxes', 'solar_shining_factor']

    phase: phase_cls = phase_cls
    """
    phase child of recirculation_outlet_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of recirculation_outlet_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of recirculation_outlet_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of recirculation_outlet_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of recirculation_outlet_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of recirculation_outlet_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of recirculation_outlet_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of recirculation_outlet_child.
    """
    flow_spec: flow_spec_cls = flow_spec_cls
    """
    flow_spec child of recirculation_outlet_child.
    """
    mass_flow: mass_flow_cls = mass_flow_cls
    """
    mass_flow child of recirculation_outlet_child.
    """
    mass_flux: mass_flux_cls = mass_flux_cls
    """
    mass_flux child of recirculation_outlet_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of recirculation_outlet_child.
    """
    solar_shining_factor: solar_shining_factor_cls = solar_shining_factor_cls
    """
    solar_shining_factor child of recirculation_outlet_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_simulation_reports import list_simulation_reports as list_simulation_reports_cls
from .generate_simulation_report import generate_simulation_report as generate_simulation_report_cls
from .view_simulation_report import view_simulation_report as view_simulation_report_cls
from .export_simulation_report_as_pdf import export_simulation_report_as_pdf as export_simulation_report_as_pdf_cls
from .export_simulation_report_as_html import export_simulation_report_as_html as export_simulation_report_as_html_cls
from .export_simulation_report_as_pptx import export_simulation_report_as_pptx as export_simulation_report_as_pptx_cls
from .write_simulation_report_names_to_file import write_simulation_report_names_to_file as write_simulation_report_names_to_file_cls
from .rename_simulation_report import rename_simulation_report as rename_simulation_report_cls
from .duplicate_simulation_report import duplicate_simulation_report as duplicate_simulation_report_cls
from .reset_report_to_defaults import reset_report_to_defaults as reset_report_to_defaults_cls
from .delete_simulation_report import delete_simulation_report as delete_simulation_report_cls
from .write_simulation_report_template_file import write_simulation_report_template_file as write_simulation_report_template_file_cls
from .read_simulation_report_template_file import read_simulation_report_template_file as read_simulation_report_template_file_cls
class simulation_reports(Group):
    """
    'simulation_reports' child.
    """

    fluent_name = "simulation-reports"

    command_names = \
        ['list_simulation_reports', 'generate_simulation_report',
         'view_simulation_report', 'export_simulation_report_as_pdf',
         'export_simulation_report_as_html',
         'export_simulation_report_as_pptx',
         'write_simulation_report_names_to_file', 'rename_simulation_report',
         'duplicate_simulation_report', 'reset_report_to_defaults',
         'delete_simulation_report', 'write_simulation_report_template_file',
         'read_simulation_report_template_file']

    list_simulation_reports: list_simulation_reports_cls = list_simulation_reports_cls
    """
    list_simulation_reports command of simulation_reports.
    """
    generate_simulation_report: generate_simulation_report_cls = generate_simulation_report_cls
    """
    generate_simulation_report command of simulation_reports.
    """
    view_simulation_report: view_simulation_report_cls = view_simulation_report_cls
    """
    view_simulation_report command of simulation_reports.
    """
    export_simulation_report_as_pdf: export_simulation_report_as_pdf_cls = export_simulation_report_as_pdf_cls
    """
    export_simulation_report_as_pdf command of simulation_reports.
    """
    export_simulation_report_as_html: export_simulation_report_as_html_cls = export_simulation_report_as_html_cls
    """
    export_simulation_report_as_html command of simulation_reports.
    """
    export_simulation_report_as_pptx: export_simulation_report_as_pptx_cls = export_simulation_report_as_pptx_cls
    """
    export_simulation_report_as_pptx command of simulation_reports.
    """
    write_simulation_report_names_to_file: write_simulation_report_names_to_file_cls = write_simulation_report_names_to_file_cls
    """
    write_simulation_report_names_to_file command of simulation_reports.
    """
    rename_simulation_report: rename_simulation_report_cls = rename_simulation_report_cls
    """
    rename_simulation_report command of simulation_reports.
    """
    duplicate_simulation_report: duplicate_simulation_report_cls = duplicate_simulation_report_cls
    """
    duplicate_simulation_report command of simulation_reports.
    """
    reset_report_to_defaults: reset_report_to_defaults_cls = reset_report_to_defaults_cls
    """
    reset_report_to_defaults command of simulation_reports.
    """
    delete_simulation_report: delete_simulation_report_cls = delete_simulation_report_cls
    """
    delete_simulation_report command of simulation_reports.
    """
    write_simulation_report_template_file: write_simulation_report_template_file_cls = write_simulation_report_template_file_cls
    """
    write_simulation_report_template_file command of simulation_reports.
    """
    read_simulation_report_template_file: read_simulation_report_template_file_cls = read_simulation_report_template_file_cls
    """
    read_simulation_report_template_file command of simulation_reports.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_ids import zone_ids as zone_ids_cls
from .retain_instantaneous_values import retain_instantaneous_values as retain_instantaneous_values_cls
from .old_props import old_props as old_props_cls
from .zone_names import zone_names as zone_names_cls
from .zone_list import zone_list as zone_list_cls
from .average_over import average_over as average_over_cls
from .per_zone import per_zone as per_zone_cls
class mesh_child(Group):
    """
    'child_object_type' of mesh.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['zone_ids', 'retain_instantaneous_values', 'old_props', 'zone_names',
         'zone_list', 'average_over', 'per_zone']

    zone_ids: zone_ids_cls = zone_ids_cls
    """
    zone_ids child of mesh_child.
    """
    retain_instantaneous_values: retain_instantaneous_values_cls = retain_instantaneous_values_cls
    """
    retain_instantaneous_values child of mesh_child.
    """
    old_props: old_props_cls = old_props_cls
    """
    old_props child of mesh_child.
    """
    zone_names: zone_names_cls = zone_names_cls
    """
    zone_names child of mesh_child.
    """
    zone_list: zone_list_cls = zone_list_cls
    """
    zone_list child of mesh_child.
    """
    average_over: average_over_cls = average_over_cls
    """
    average_over child of mesh_child.
    """
    per_zone: per_zone_cls = per_zone_cls
    """
    per_zone child of mesh_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .flow_cp_interpolation_enabled import flow_cp_interpolation_enabled as flow_cp_interpolation_enabled_cls
from .flow_density_interpolation_enabled import flow_density_interpolation_enabled as flow_density_interpolation_enabled_cls
from .flow_gradient_interpolation_enabled import flow_gradient_interpolation_enabled as flow_gradient_interpolation_enabled_cls
from .flow_viscosity_interpolation_enabled import flow_viscosity_interpolation_enabled as flow_viscosity_interpolation_enabled_cls
from .flow_temperature_interpolation_enabled import flow_temperature_interpolation_enabled as flow_temperature_interpolation_enabled_cls
from .zero_nodal_velocities_on_walls import zero_nodal_velocities_on_walls as zero_nodal_velocities_on_walls_cls
class interpolation(Group):
    """
    Main menu holding options to enable/disable interpolation of flow data to the particle position.
    """

    fluent_name = "interpolation"

    child_names = \
        ['flow_cp_interpolation_enabled',
         'flow_density_interpolation_enabled',
         'flow_gradient_interpolation_enabled',
         'flow_viscosity_interpolation_enabled',
         'flow_temperature_interpolation_enabled',
         'zero_nodal_velocities_on_walls']

    flow_cp_interpolation_enabled: flow_cp_interpolation_enabled_cls = flow_cp_interpolation_enabled_cls
    """
    flow_cp_interpolation_enabled child of interpolation.
    """
    flow_density_interpolation_enabled: flow_density_interpolation_enabled_cls = flow_density_interpolation_enabled_cls
    """
    flow_density_interpolation_enabled child of interpolation.
    """
    flow_gradient_interpolation_enabled: flow_gradient_interpolation_enabled_cls = flow_gradient_interpolation_enabled_cls
    """
    flow_gradient_interpolation_enabled child of interpolation.
    """
    flow_viscosity_interpolation_enabled: flow_viscosity_interpolation_enabled_cls = flow_viscosity_interpolation_enabled_cls
    """
    flow_viscosity_interpolation_enabled child of interpolation.
    """
    flow_temperature_interpolation_enabled: flow_temperature_interpolation_enabled_cls = flow_temperature_interpolation_enabled_cls
    """
    flow_temperature_interpolation_enabled child of interpolation.
    """
    zero_nodal_velocities_on_walls: zero_nodal_velocities_on_walls_cls = zero_nodal_velocities_on_walls_cls
    """
    zero_nodal_velocities_on_walls child of interpolation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .general_1 import general as general_cls
from .geometry_1 import geometry as geometry_cls
from .trimming import trimming as trimming_cls
class rotor_child(Group):
    """
    'child_object_type' of rotor.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'general', 'geometry', 'trimming']

    name: name_cls = name_cls
    """
    name child of rotor_child.
    """
    general: general_cls = general_cls
    """
    general child of rotor_child.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of rotor_child.
    """
    trimming: trimming_cls = trimming_cls
    """
    trimming child of rotor_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .unit_system import unit_system as unit_system_cls
class set_unit_system(Command):
    """
    To apply standard set of units to all quantities.
    
    Parameters
    ----------
        unit_system : str
            'unit_system' child.
    
    """

    fluent_name = "set-unit-system"

    argument_names = \
        ['unit_system']

    unit_system: unit_system_cls = unit_system_cls
    """
    unit_system argument of set_unit_system.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class raytracer_image(Boolean):
    """
    Enable advanced raytracing for hardcopy and preview.
    """

    fluent_name = "raytracer-image?"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class outflow:
    fluent_name = ...
    command_names = ...

    def change_type(self, zone_list: List[str], new_type: str):
        """
        'change_type' command.
        
        Parameters
        ----------
            zone_list : typing.List[str]
                'zone_list' child.
            new_type : str
                'new_type' child.
        
        """

    <class 'ansys.fluent.core.solver.flobject.child_object_type'> = ...



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class auto:
    fluent_name = ...
    child_names = ...
    across_zones = ...
    method = ...
    load_vector = ...
    pre_test = ...
    command_names = ...

    def use_case_file_method(self, file_partition_method: bool):
        """
        Enable the use-case-file method for auto partitioning.
        
        Parameters
        ----------
            file_partition_method : bool
                'file_partition_method' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .options_1 import options as options_cls
from .convert_domain import convert_domain as convert_domain_cls
from .convert_hanging_nodes import convert_hanging_nodes as convert_hanging_nodes_cls
from .convert_hanging_node_zones import convert_hanging_node_zones as convert_hanging_node_zones_cls
from .convert_skewed_cells_1 import convert_skewed_cells as convert_skewed_cells_cls
class polyhedra(Group):
    """
    Enter the polyhedra menu.
    """

    fluent_name = "polyhedra"

    child_names = \
        ['options']

    options: options_cls = options_cls
    """
    options child of polyhedra.
    """
    command_names = \
        ['convert_domain', 'convert_hanging_nodes',
         'convert_hanging_node_zones', 'convert_skewed_cells']

    convert_domain: convert_domain_cls = convert_domain_cls
    """
    convert_domain command of polyhedra.
    """
    convert_hanging_nodes: convert_hanging_nodes_cls = convert_hanging_nodes_cls
    """
    convert_hanging_nodes command of polyhedra.
    """
    convert_hanging_node_zones: convert_hanging_node_zones_cls = convert_hanging_node_zones_cls
    """
    convert_hanging_node_zones command of polyhedra.
    """
    convert_skewed_cells: convert_skewed_cells_cls = convert_skewed_cells_cls
    """
    convert_skewed_cells command of polyhedra.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class root:
    fluent_name = ...
    child_names = ...
    file = ...
    mesh = ...
    server = ...
    setup = ...
    solution = ...
    results = ...
    parametric_studies = ...
    current_parametric_study = ...
    parallel = ...
    report = ...
    command_names = ...

    def exit(self, ):
        """
        Exit program.
        """




import re


class IncompleteISOSurfaceDefinition(RuntimeError):
    """Provides the error when iso-surface definition is incomplete."""

    def __init__(self):
        super().__init__("Iso surface definition is incomplete.")


class SurfaceCreationError(RuntimeError):
    """Provides the error when surface creation is unsuccessful."""

    def __init__(self):
        super().__init__("Surface creation is unsuccessful.")


class PostAPIHelper:
    """Class providing helper API for post objects."""

    class _SurfaceAPI:
        """Class providing APIs for surface operations."""

        def __init__(self, obj):
            self.obj = obj
            self._surface_name_on_server = self.surface_name_on_server(obj._name)

        @staticmethod
        def surface_name_on_server(local_surface_name):
            """Returns the surface name on server."""
            return "_dummy_surface_for_pyfluent:" + local_surface_name.lower()

        def _get_api_handle(self):
            return self.obj.get_root().session.tui.surface

        def _delete_if_exist_on_server(self):
            field_info = self.obj._api_helper.field_info()
            surfaces_list = list(field_info.get_surfaces_info().keys())
            if self._surface_name_on_server in surfaces_list:
                self.delete_surface_on_server()

        def create_surface_on_server(self):
            """Creates the surface on server.

            Raises
            ------
            IncompleteISOSurfaceDefinition
                If iso-surface definition is incomplete.
            SurfaceCreationError
                If server fails to create surface.
            """
            if self.obj.definition.type() == "iso-surface":
                iso_surface = self.obj.definition.iso_surface
                field = iso_surface.field()
                iso_value = iso_surface.iso_value()
                if not field:
                    raise IncompleteISOSurfaceDefinition()
                self._delete_if_exist_on_server()
                phases = self.obj._api_helper._get_phases()
                unit_quantity = self.obj._api_helper._field_unit_quantity(field)
                unit_info = self.obj._api_helper._fluent_unit_info(unit_quantity)
                if phases:
                    phases = list(filter(field.startswith, phases))
                    if phases:
                        domain, field = (
                            field[0 : len(phases[0])],
                            field[len(phases[0]) + 1 :],
                        )
                    else:
                        domain = "mixture"
                    self._get_api_handle().iso_surface(
                        domain,
                        field,
                        self._surface_name_on_server,
                        (),
                        (),
                        (iso_value / unit_info[1]) - unit_info[2],
                        (),
                    )
                else:
                    self._get_api_handle().iso_surface(
                        field,
                        self._surface_name_on_server,
                        (),
                        (),
                        (iso_value / unit_info[1]) - unit_info[2],
                        (),
                    )
            elif self.obj.definition.type() == "plane-surface":
                plane_surface = self.obj.definition.plane_surface
                xy_plane = plane_surface.xy_plane
                yz_plane = plane_surface.yz_plane
                zx_plane = plane_surface.zx_plane
                self._delete_if_exist_on_server()
                unit_info = self.obj._api_helper._fluent_unit_info("length")
                self._get_api_handle().plane_surface(
                    self._surface_name_on_server,
                    "xy-plane" if xy_plane else "yz-plane" if yz_plane else "zx-plane",
                    (xy_plane.z() / unit_info[1]) - unit_info[2]
                    if xy_plane
                    else (yz_plane.x() / unit_info[1]) - unit_info[2]
                    if yz_plane
                    else (zx_plane.y() / unit_info[1]) - unit_info[2],
                )
            field_info = self.obj._api_helper.field_info()
            surfaces_list = list(field_info.get_surfaces_info().keys())
            if self._surface_name_on_server not in surfaces_list:
                raise SurfaceCreationError()

        def delete_surface_on_server(self):
            """Deletes the surface on server."""
            self._get_api_handle().delete_surface(self._surface_name_on_server)

    def __init__(self, obj):
        """__init__ method of PostAPIHelper class."""
        self.obj = obj
        self.field_info = lambda: obj.get_root().session.field_info
        self.field_data = lambda: obj.get_root().session.field_data
        self.monitors_manager = lambda: obj.get_root().session.monitors_manager
        self.id = lambda: obj.get_root().session.id
        if obj.__class__.__name__ == "Surface":
            self.surface_api = PostAPIHelper._SurfaceAPI(obj)

    def remote_surface_name(self, local_surface_name):
        """Returns the surface name."""

        local_surfaces_provider = self.obj.get_root()._local_surfaces_provider()

        if local_surface_name in list(local_surfaces_provider):
            return PostAPIHelper._SurfaceAPI.surface_name_on_server(local_surface_name)
        else:
            return local_surface_name

    # Following functions will be deprecated in future.
    def get_vector_fields(self):
        """Returns vector field."""
        scheme_eval_str = "(map car (apply append (map client-inquire-cell-vector-functions (inquire-domain-for-cell-functions))))"  # noqa: E501
        return self._scheme_str_to_py_list(scheme_eval_str)

    def get_field_unit(self, field):
        """Returns the unit of the field."""
        quantity = self._field_unit_quantity(field)
        if quantity == "*null*":
            return ""
        scheme_eval_str = f"(units/get-pretty-wb-units-from-dimension (units/inquire-dimension '{quantity}))"  # noqa: E501
        return " ".join(self._scheme_str_to_py_list(scheme_eval_str))

    def _get_phases(self):
        scheme_eval_str = "(map domain-name (get-phase-domains))"
        return self._scheme_str_to_py_list(scheme_eval_str)

    def _field_unit_quantity(self, field):
        scheme_eval_str = f"(cdr (assq 'units (%fill-render-info '{field})))"
        return self._scheme_str_to_py_list(scheme_eval_str)[0]

    def _fluent_unit_info(self, unit_quantity):
        def to_float(number):
            try:
                return float(number)
            except ValueError:
                return number

        scheme_eval_str = (
            f"(units/inquire-label-scale-offset-for-quantity '{unit_quantity})"
        )
        unit_info = [
            to_float(data) for data in self._scheme_str_to_py_list(scheme_eval_str)
        ]
        if len(unit_info) == 2:
            unit_info.insert(0, "")
        return unit_info

    def _scheme_str_to_py_list(self, scheme_eval_str):
        session = self.obj.get_root().session
        if hasattr(session, "scheme_eval"):
            str_val = session.scheme_eval.string_eval(scheme_eval_str)
            return list(filter(None, re.split(r'[\s()"\']', str_val)))
        else:
            return ["*null*"]



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .surface_2 import surface as surface_cls
from .center_of_rotation import center_of_rotation as center_of_rotation_cls
from .angle_of_rotation import angle_of_rotation as angle_of_rotation_cls
from .translation_distance import translation_distance as translation_distance_cls
from .iso_distance import iso_distance as iso_distance_cls
from .display_3 import display as display_cls
class transform_surface_child(Group):
    """
    'child_object_type' of transform_surface.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'surface', 'center_of_rotation', 'angle_of_rotation',
         'translation_distance', 'iso_distance']

    name: name_cls = name_cls
    """
    name child of transform_surface_child.
    """
    surface: surface_cls = surface_cls
    """
    surface child of transform_surface_child.
    """
    center_of_rotation: center_of_rotation_cls = center_of_rotation_cls
    """
    center_of_rotation child of transform_surface_child.
    """
    angle_of_rotation: angle_of_rotation_cls = angle_of_rotation_cls
    """
    angle_of_rotation child of transform_surface_child.
    """
    translation_distance: translation_distance_cls = translation_distance_cls
    """
    translation_distance child of transform_surface_child.
    """
    iso_distance: iso_distance_cls = iso_distance_cls
    """
    iso_distance child of transform_surface_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of transform_surface_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_name_1 import zone_name as zone_name_cls
class slit_face_zone(Command):
    """
    Slit a two-sided wall into two connected wall zones.
    
    Parameters
    ----------
        zone_name : str
            Enter a zone name.
    
    """

    fluent_name = "slit-face-zone"

    argument_names = \
        ['zone_name']

    zone_name: zone_name_cls = zone_name_cls
    """
    zone_name argument of slit_face_zone.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .adaptive_time_stepping import adaptive_time_stepping as adaptive_time_stepping_cls
from .cfl_based_adaptive_time_stepping import cfl_based_adaptive_time_stepping as cfl_based_adaptive_time_stepping_cls
from .data_sampling_1 import data_sampling as data_sampling_cls
from .transient_controls import transient_controls as transient_controls_cls
from .pseudo_time_settings import pseudo_time_settings as pseudo_time_settings_cls
from .data_sampling_options import data_sampling_options as data_sampling_options_cls
from .iter_count_2 import iter_count as iter_count_cls
from .reporting_interval import reporting_interval as reporting_interval_cls
from .residual_verbosity import residual_verbosity as residual_verbosity_cls
from .time_step_count_2 import time_step_count as time_step_count_cls
from .dual_time_iterate import dual_time_iterate as dual_time_iterate_cls
from .iterate import iterate as iterate_cls
from .calculate import calculate as calculate_cls
from .interrupt import interrupt as interrupt_cls
from .iterating import iterating as iterating_cls
class run_calculation(Group):
    """
    'run_calculation' child.
    """

    fluent_name = "run-calculation"

    child_names = \
        ['adaptive_time_stepping', 'cfl_based_adaptive_time_stepping',
         'data_sampling', 'transient_controls', 'pseudo_time_settings',
         'data_sampling_options', 'iter_count', 'reporting_interval',
         'residual_verbosity', 'time_step_count']

    adaptive_time_stepping: adaptive_time_stepping_cls = adaptive_time_stepping_cls
    """
    adaptive_time_stepping child of run_calculation.
    """
    cfl_based_adaptive_time_stepping: cfl_based_adaptive_time_stepping_cls = cfl_based_adaptive_time_stepping_cls
    """
    cfl_based_adaptive_time_stepping child of run_calculation.
    """
    data_sampling: data_sampling_cls = data_sampling_cls
    """
    data_sampling child of run_calculation.
    """
    transient_controls: transient_controls_cls = transient_controls_cls
    """
    transient_controls child of run_calculation.
    """
    pseudo_time_settings: pseudo_time_settings_cls = pseudo_time_settings_cls
    """
    pseudo_time_settings child of run_calculation.
    """
    data_sampling_options: data_sampling_options_cls = data_sampling_options_cls
    """
    data_sampling_options child of run_calculation.
    """
    iter_count: iter_count_cls = iter_count_cls
    """
    iter_count child of run_calculation.
    """
    reporting_interval: reporting_interval_cls = reporting_interval_cls
    """
    reporting_interval child of run_calculation.
    """
    residual_verbosity: residual_verbosity_cls = residual_verbosity_cls
    """
    residual_verbosity child of run_calculation.
    """
    time_step_count: time_step_count_cls = time_step_count_cls
    """
    time_step_count child of run_calculation.
    """
    command_names = \
        ['dual_time_iterate', 'iterate', 'calculate', 'interrupt']

    dual_time_iterate: dual_time_iterate_cls = dual_time_iterate_cls
    """
    dual_time_iterate command of run_calculation.
    """
    iterate: iterate_cls = iterate_cls
    """
    iterate command of run_calculation.
    """
    calculate: calculate_cls = calculate_cls
    """
    calculate command of run_calculation.
    """
    interrupt: interrupt_cls = interrupt_cls
    """
    interrupt command of run_calculation.
    """
    query_names = \
        ['iterating']

    iterating: iterating_cls = iterating_cls
    """
    iterating query of run_calculation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .scheme import scheme as scheme_cls
from .low_order_scheme import low_order_scheme as low_order_scheme_cls
from .high_order_scheme import high_order_scheme as high_order_scheme_cls
from .accuracy_control import accuracy_control as accuracy_control_cls
class tracking(Group):
    """
    'tracking' child.
    """

    fluent_name = "tracking"

    child_names = \
        ['scheme', 'low_order_scheme', 'high_order_scheme',
         'accuracy_control']

    scheme: scheme_cls = scheme_cls
    """
    scheme child of tracking.
    """
    low_order_scheme: low_order_scheme_cls = low_order_scheme_cls
    """
    low_order_scheme child of tracking.
    """
    high_order_scheme: high_order_scheme_cls = high_order_scheme_cls
    """
    high_order_scheme child of tracking.
    """
    accuracy_control: accuracy_control_cls = accuracy_control_cls
    """
    accuracy_control child of tracking.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class support_for_std_track_data_read_enabled(Boolean):
    """
    Enable/disable data-read verification, preventing particle loss when transitioning between standard and high-res tracking.
    """

    fluent_name = "support-for-std-track-data-read-enabled?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .buoyancy_force_linearization import buoyancy_force_linearization as buoyancy_force_linearization_cls
from .blended_treatment_for_buoyancy_forces import blended_treatment_for_buoyancy_forces as blended_treatment_for_buoyancy_forces_cls
class coupled_vof(Group):
    """
    'coupled_vof' child.
    """

    fluent_name = "coupled-vof"

    child_names = \
        ['buoyancy_force_linearization',
         'blended_treatment_for_buoyancy_forces']

    buoyancy_force_linearization: buoyancy_force_linearization_cls = buoyancy_force_linearization_cls
    """
    buoyancy_force_linearization child of coupled_vof.
    """
    blended_treatment_for_buoyancy_forces: blended_treatment_for_buoyancy_forces_cls = blended_treatment_for_buoyancy_forces_cls
    """
    blended_treatment_for_buoyancy_forces child of coupled_vof.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_properties import list_properties as list_properties_cls
from .list_all import list_all as list_all_cls
from .expert_child import expert_child

class expert(ListObject[expert_child]):
    """
    Expert options in Park's model.
    """

    fluent_name = "expert"

    command_names = \
        ['list_properties', 'list_all']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of expert.
    """
    list_all: list_all_cls = list_all_cls
    """
    list_all command of expert.
    """
    child_object_type: expert_child = expert_child
    """
    child_object_type of expert.
    """



"""Functions to download sample datasets from the Ansys example data repository."""
import logging
import os
from pathlib import Path
import re
import shutil
from typing import Optional
import zipfile

import requests

import ansys.fluent.core as pyfluent

logger = logging.getLogger("pyfluent.networking")


def delete_downloads():
    """Delete all downloaded examples from the default examples folder to free space or
    update the files.

    Notes
    -----
    The default examples path is given by ``pyfluent.EXAMPLES_PATH``.
    """
    shutil.rmtree(pyfluent.EXAMPLES_PATH)
    os.makedirs(pyfluent.EXAMPLES_PATH)


def _decompress(file_name: str) -> None:
    """Decompress zipped file."""
    zip_ref = zipfile.ZipFile(file_name, "r")
    zip_ref.extractall(pyfluent.EXAMPLES_PATH)
    return zip_ref.close()


def _get_file_url(file_name: str, directory: Optional[str] = None) -> str:
    """Get file URL."""
    if directory:
        return (
            "https://github.com/ansys/example-data/raw/master/"
            f"{directory}/{file_name}"
        )
    return f"https://github.com/ansys/example-data/raw/master/{file_name}"


def _retrieve_file(
    url: str,
    file_name: str,
    save_path: Optional[str] = None,
    return_without_path: Optional[bool] = False,
) -> str:
    """Download specified file from specified URL."""
    file_name = os.path.basename(file_name)
    if save_path is None:
        save_path = pyfluent.EXAMPLES_PATH
    else:
        save_path = os.path.abspath(save_path)
    local_path = os.path.join(save_path, file_name)
    local_path_no_zip = re.sub(".zip$", "", local_path)
    file_name_no_zip = re.sub(".zip$", "", file_name)
    # First check if file has already been downloaded
    logger.info(f"Checking if {local_path_no_zip} already exists...")
    if os.path.isfile(local_path_no_zip) or os.path.isdir(local_path_no_zip):
        print(f"File already exists. File path:\n{local_path_no_zip}")
        logger.info("File already exists.")
        if return_without_path:
            return file_name_no_zip
        else:
            return local_path_no_zip

    logger.info("File does not exist. Downloading specified file...")

    # Check if save path exists
    if not os.path.exists(save_path):
        os.makedirs(save_path)

    # Download file
    logger.info(f'Downloading URL: "{url}"')
    content = requests.get(url).content
    with open(local_path, "wb") as f:
        f.write(content)

    if local_path.endswith(".zip"):
        _decompress(local_path)
        local_path = local_path_no_zip
        file_name = file_name_no_zip
    print(f"Download successful. File path:\n{local_path}")
    logger.info("Download successful.")
    if return_without_path:
        return file_name
    else:
        return local_path


def download_file(
    file_name: str,
    directory: Optional[str] = None,
    save_path: Optional[str] = None,
    return_without_path: Optional[bool] = None,
) -> str:
    """Download specified example file from the Ansys example data repository.

    Parameters
    ----------
    file_name : str
        File to download.
    directory : str, optional
        Ansys example data repository directory where specified file is located. If not specified, looks for the file
        in the root directory of the repository.
    save_path : str, optional
        Path to download the specified file to.
    return_without_path : bool, optional
        When unspecified, defaults to False, unless the PYFLUENT_LAUNCH_CONTAINER=1 environment variable is specified,
        in which case defaults to True.
        Relevant when using Fluent Docker container images, as the full path for the imported file from
        the host side is not necessarily going to be the same as the one for Fluent inside the container.
        Assuming the Fluent inside the container has its working directory set to the path that was mounted from
        the host, and that the example files are being made available by the host through this same path,
        only the file name is required for Fluent to find and open the file.

    Returns
    -------
    str
        file path of the downloaded or already existing file, or only the file name if ``return_without_path=True``.

    Examples
    --------
    >>> from ansys.fluent.core import examples
    >>> file_path = examples.download_file("bracket.iges", "geometry")
    >>> file_path
    '/home/user/.local/share/ansys_fluent_core/examples/bracket.iges'
    >>> file_name = examples.download_file("bracket.iges", "geometry", return_without_path=True)
    >>> file_name
    'bracket.iges'
    >>> file_path = examples.download_file("bracket.iges", "geometry", save_path='.')
    '/home/<current_folder_path>/bracket.iges'
    >>> file_name = examples.download_file("bracket.iges", "geometry", save_path='.', return_without_path=True)
    >>> file_name
    'bracket.iges'
    >>> file_path = examples.download_file("bracket.iges", "geometry", save_path='<user_specified_path>')
    '/home/<user_specified_path>/bracket.iges'
    >>> file_name = examples.download_file("bracket.iges", "geometry", save_path='<user_specified_path>',
    ...                                   return_without_path=True)
    >>> file_name
    'bracket.iges'
    """
    if return_without_path is None:
        if os.getenv("PYFLUENT_LAUNCH_CONTAINER") == "1":
            return_without_path = True
        else:
            return_without_path = False

    url = _get_file_url(file_name, directory)
    return _retrieve_file(url, file_name, save_path, return_without_path)


def path(file_name: str):
    if os.path.isabs(file_name):
        return file_name
    file_path = Path(pyfluent.EXAMPLES_PATH) / file_name
    if file_path.is_file():
        return str(file_path)
    else:
        raise FileNotFoundError(f"{file_name} does not exist.")



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .transient_parameters_specify import transient_parameters_specify as transient_parameters_specify_cls
from .transient_scheme import transient_scheme as transient_scheme_cls
from .time_scale_modification_method import time_scale_modification_method as time_scale_modification_method_cls
from .time_scale_modification_factor import time_scale_modification_factor as time_scale_modification_factor_cls
class transient(Group):
    """
    'transient' child.
    """

    fluent_name = "transient"

    child_names = \
        ['transient_parameters_specify', 'transient_scheme',
         'time_scale_modification_method', 'time_scale_modification_factor']

    transient_parameters_specify: transient_parameters_specify_cls = transient_parameters_specify_cls
    """
    transient_parameters_specify child of transient.
    """
    transient_scheme: transient_scheme_cls = transient_scheme_cls
    """
    transient_scheme child of transient.
    """
    time_scale_modification_method: time_scale_modification_method_cls = time_scale_modification_method_cls
    """
    time_scale_modification_method child of transient.
    """
    time_scale_modification_factor: time_scale_modification_factor_cls = time_scale_modification_factor_cls
    """
    time_scale_modification_factor child of transient.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .rich_equivalence_ratio_limit import rich_equivalence_ratio_limit as rich_equivalence_ratio_limit_cls
from .exponential_factor_beta import exponential_factor_beta as exponential_factor_beta_cls
class equilibrium_rich_flammability_options(Group):
    """
    'equilibrium_rich_flammability_options' child.
    """

    fluent_name = "equilibrium-rich-flammability-options"

    child_names = \
        ['rich_equivalence_ratio_limit', 'exponential_factor_beta']

    rich_equivalence_ratio_limit: rich_equivalence_ratio_limit_cls = rich_equivalence_ratio_limit_cls
    """
    rich_equivalence_ratio_limit child of equilibrium_rich_flammability_options.
    """
    exponential_factor_beta: exponential_factor_beta_cls = exponential_factor_beta_cls
    """
    exponential_factor_beta child of equilibrium_rich_flammability_options.
    """
